//
//  ViewController.m
//  keyBoard
//
//  Created by yangyu on 16/7/5.
//  Copyright © 2016年 yangyu. All rights reserved.
//

#import "ViewController.h"
#import "TableViewCell.h"
#import "keyBoardToolView.h"
@interface ViewController ()<UITableViewDelegate,UITableViewDataSource,TableViewCellDelegate,keyBoardToolViewDelegate>
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) keyBoardToolView *keyBoardView;
@property (nonatomic, assign) CGFloat keyBoardHeight;
@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [self registerKeyBoardNotification];
    [self.view addSubview:self.tableView];
    [self initWithKeyBoardToolView];
}

- (void)initWithKeyBoardToolView {
    self.keyBoardView = [[keyBoardToolView alloc] initWithFrame:CGRectMake(0, self.view.frame.size.height, self.view.frame.size.width, 40)];
    self.keyBoardView.backgroundColor = [UIColor grayColor];
    self.keyBoardView.delegate = self;
    [self.view addSubview:self.keyBoardView];
}

- (void)registerKeyBoardNotification {
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(handleKeyBoardHide:) name:UIKeyboardWillShowNotification object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(handleKeyBoardAction:) name:UIKeyboardWillHideNotification object:nil];
}

- (void)handleKeyBoardHide:(NSNotification *)notification {
    CGRect rect = [notification.userInfo[UIKeyboardFrameEndUserInfoKey] CGRectValue];
    double duration = [notification.userInfo[UIKeyboardAnimationDurationUserInfoKey] doubleValue];
    self.keyBoardHeight = rect.size.height;
    [UIView animateWithDuration:duration animations:^{
        self.keyBoardView.frame = CGRectMake(0, self.view.frame.size.height - self.keyBoardHeight - 44,self.view.frame.size.width, 40);
    }];
}

- (void)handleKeyBoardAction:(NSNotification *)notification {
    double duration = [notification.userInfo[UIKeyboardAnimationDurationUserInfoKey] doubleValue];
    [UIView animateWithDuration:duration animations:^{
        self.keyBoardView.frame = CGRectMake(0, self.view.frame.size.height,self.view.frame.size.width, 40);
    }];
}

- (UITableView *)tableView {
    if (!_tableView) {
        _tableView = [[UITableView alloc] initWithFrame:CGRectMake(0, 0, self.view.frame.size.width, self.view.frame.size.height) style:UITableViewStylePlain];
        [_tableView registerNib:[UINib nibWithNibName:@"TableViewCell" bundle:nil] forCellReuseIdentifier:@"ID"];
        _tableView.delegate = self;
        _tableView.dataSource = self;
        _tableView.rowHeight = 100;
        _tableView.keyboardDismissMode = UIScrollViewKeyboardDismissModeOnDrag;
    }
    return _tableView;
}


- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return 10;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [self.keyBoardView.textView resignFirstResponder];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    TableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"ID" forIndexPath:indexPath];
    cell.delegate = self;
    return cell;
}

- (void)tableViewCell:(TableViewCell *)cell commentses:(UIButton *)commentsBtn {
    [self.keyBoardView.textView becomeFirstResponder];
    NSLog(@"按钮点击 = %f",CGRectGetMaxY(cell.contentView.frame));
    UIWindow *window = [UIApplication sharedApplication].keyWindow;
    CGRect rect = [commentsBtn convertRect:commentsBtn.bounds toView:window];
    [self keyBoardWindowCGRect:rect];
    NSLog(@"%f",CGRectGetMaxY(rect));
}

//处理键盘
- (void)keyBoardWindowCGRect:(CGRect)rect {
    CGPoint offset = self.tableView.contentOffset;
    offset.y += rect.origin.y + 40 - ([UIScreen mainScreen].bounds.size.height - self.keyBoardHeight - 40);;
    if (offset.y < 0) {
        offset.y = 0;
    }
    [UIView animateWithDuration:0.25 animations:^{
        self.tableView.contentOffset = offset;
    }];
}

- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event {
    [self.view endEditing:YES];
}

- (void)keyBoardToolShouldEndEditing:(UITextView *)textView {
    NSLog(@"%@",textView.text);
}
@end
